============================================================================================================
bisos.csPlayer: Blee-CS-Player: A Blee (ByStar Libre-Halaal Emacs Environment) CS (Command Services) Player.
============================================================================================================

.. contents::
   :depth: 3
..

Overview
========

Blee-CS-Player: A Blee (ByStar Libre-Halaal Emacs Environment) CS
(Command Services) Player.

Takes an CS as input and allows for its command-line execution through a
rich interactive emacs inteface. Emacs dynamic interactions are
implemented based on org-mode dynamic blocks.

Package Documentation At Github
===============================

The information below is a subset of the full of documentation for this
bisos-pip package. More complete documentation is available at:
https://github.com/bisos-pip/csPlayer-cs

Realted Resources
=================

+--------------------------+------------------------------------------+
| bisos Capabilities Panel | file:/panels/capab                       |
|                          | ilities/_nodeBase_/fullUsagePanel-en.org |
+--------------------------+------------------------------------------+
|                          |                                          |
+--------------------------+------------------------------------------+

.. _table-of-contents:

Table of Contents TOC
=====================

-  `Overview <#overview>`__
-  `Package Documentation At
   Github <#package-documentation-at-github>`__
-  `Realted Resources <#realted-resources>`__
-  `Installation <#installation>`__

   -  `Installation With pip <#installation-with-pip>`__
   -  `Installation With pipx <#installation-with-pipx>`__

-  `Part of BISOS and ByStar — ByStar Internet Services Operating
   System <#part-of-bisos-and-bystar-----bystar-internet-services-operating-system>`__
-  `bisos.csPlayer as a Standalone Piece of
   BISOS <#bisoscsplayer-as-a-standalone-piece-of-bisos>`__
-  `Documentation and Blee-Panels <#documentation-and-blee-panels>`__

   -  `bisos.csPlayer Blee-Panels <#bisoscsplayer-blee-panels>`__

-  `Support <#support>`__

Installation
============

The sources for the bisos.csPlayer pip package is maintained at:
https://github.com/bisos-pip/csPlayer.

The bisos.csPlayer pip package is available at PYPI as
https://pypi.org/project/bisos.csPlayer

You can install bisos.csPlayer with pip or pipx.

Installation With pip
---------------------

If you need access to bisos.csPlayer as a python module, you can install
it with pip:

.. code:: bash

   pip install bisos.csPlayer

Installation With pipx
----------------------

If you only need access to bisos.csPlayer as a command on command-line,
you can install it with pipx:

.. code:: bash

   pipx install bisos.csPlayer

The following commands are made available:

-  bleeIcmPlayer.py

Part of BISOS and ByStar — ByStar Internet Services Operating System
====================================================================

| Layered on top of Debian, **BISOS**: (By\* Internet Services Operating
  System) is a unified and universal framework for developing both
  internet services and software-service continuums that use internet
  services. See `Bootstrapping ByStar, BISOS and
  Blee <https://github.com/bxGenesis/start>`__ for information about
  getting started with BISOS.
| **BISOS** is a foundation for **The Libre-Halaal ByStar Digital
  Ecosystem** which is described as a cure for losses of autonomy and
  privacy in a book titled: `Nature of
  Polyexistentials <https://github.com/bxplpc/120033>`__

*bisos.csPlayer* is part of BISOS.

bisos.csPlayer as a Standalone Piece of BISOS
=============================================

bisos.csPlayer is a standalone piece of BISOS. It can be used as a
self-contained Python package separate from BISOS. Follow the
installation and usage instructions below for your own use.

Documentation and Blee-Panels
=============================

bisos.csPlayer is part of ByStar Digital Ecosystem
http://www.by-star.net.

This module's primary documentation is in the form of Blee-Panels.
Additional information is also available in:
http://www.by-star.net/PLPC/180047

bisos.csPlayer Blee-Panels
--------------------------

bisos.csPlayer Blee-Panels are in ./panels directory. From within Blee
and BISOS these panels are accessible under the Blee "Panels" menu.

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact
